/********************************COPYRIGHT*************************************

    Copyright (C) 2002 - 2005 Brendt Wohlberg  <os@wohlberg.net>

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this library; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

********************************COPYRIGHT*************************************/

/*
  NikonScan TIFF IFD access functions

  Most recent modification: 4 April 2005
*/

#ifndef _NSIFD_H
#define _NSIFD_H

#include <stdio.h>
#include "tiffdir.h" 

typedef struct {
  char* date;
  char* software;
  char* hardware;
  char* mknver;
  const char* filmtype;
  char* multsample;
  uint16* bitdepth;
  float* mastergain;
  float* colourgain;
  char* ice;
  uint16* roc;
  uint16* gem;
} NSSettings;


void InitNSSettings(NSSettings* nss);

void CleanNSSettings(NSSettings* nss);

int NSSetDate(NSSettings* nss, const char* date);

int NSSetSoftware(NSSettings* nss, const char* software);

int NSSetHardare(NSSettings* nss, const char* hardware);

int NSSetMakerNoteVer(NSSettings* nss, const char* mknver);

int NSSetFilmType(NSSettings* nss, const char* filmtype);

int NSSetMultiSample(NSSettings* nss, const char* multsample);

int NSSetBitDepth(NSSettings* nss, uint16 bitdepth);

int NSSetMasterGain(NSSettings* nss, int32* mastergain, int fixflag);

int NSSetColourGain(NSSettings* nss, int32* colourgain, int fixflag);

int NSSetICE(NSSettings* nss, const char* ice);

int NSSetROC(NSSettings* nss, uint16 roc);

int NSSetGEM(NSSettings* nss, uint16 gem);

void PrintNSSettings(FILE* fp, const NSSettings* nss);

#if HAVE_BZLIB_H == 1 && HAVE_LIBBZ2 == 1
FILE* BZUncompressed(const char* filename, uint32 bytes);
#endif

int NSFileRead(const char* filename, NSSettings* nss, int fixflag);

#endif
